Package: RImmPort
Type: Package
Title: RImmPort: Enabling Ready-for-analysis Immunology Research Data
Version: 1.39.0
Author: Ravi Shankar <rshankar@stanford.edu>
Maintainer: Zicheng Hu <Zicheng.Hu@ucsf.edu>, Ravi Shankar <rshankar@stanford.edu>
URL: http://bioconductor.org/packages/RImmPort/
Description: The RImmPort package simplifies access to ImmPort data for
    analysis in the R environment. It provides a standards-based
    interface to the ImmPort study data that is in a proprietary
    format.
License: GPL-3
Imports: plyr, dplyr, DBI, data.table, reshape2, methods, sqldf, tools,
        utils, RSQLite
Suggests: knitr
biocViews: BiomedicalInformatics, DataImport, DataRepresentation
VignetteBuilder: knitr
RoxygenNote: 5.0.1
NeedsCompilation: no
git_url: https://git.bioconductor.org/packages/RImmPort
git_branch: devel
git_last_commit: 61765d4
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.23
Date/Publication: 2025-10-30
Packaged: 2025-10-30 22:42:00 UTC; biocbuild
