#' RImmPort: Enabling ready-for-analysis immunology research data
#'
#' The `RImmPort` package simplifies access to ImmPort data for analysis, 
#' as the name implies, in the R statistical environment. It provides a 
#' standards-based interface to the ImmPort study data that is in a proprietary format.
#' 
#' @docType package
#' @name RImmPort
NULL
# > NULL 
