% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/GeneticsFindings.R
\name{SUPPPF}
\alias{SUPPPF}
\title{Genetics Findings Domain Supplemental Variables}
\description{
{
  \tabular{ll}{
    \strong{Variable Name} \tab \strong{Variable Label} \cr
    STUDYID \tab Study Identifier \cr
    RDOMAIN  \tab Related Domain Abbreviation \cr
    USUBJID \tab Unique Subject Identifier \cr
    IDVAR \tab Identifying Variable \cr
    IDVARVAL \tab Identifying Variable Value \cr
    QNAM \tab Qualifier Variable Name \cr
    QLABEL \tab Qualifier Variable Label \cr
    QVAL \tab Data Value
  }
}
}
\note{
The following table enumerates the values in QNAM and QLABEL variables {
  \tabular{ll}{
    \strong{QNAM} \tab \strong{QLABEL} \cr
    PFPOPAR \tab Geographic Area of the Population \cr
    PFSPECSB \tab Specimen Subtype \cr
    PFREFIDP \tab Source Specimen Identifier \cr
    VISITMIN \tab Planned Visit Minimum Start Day \cr
    VISITMAX \tab Planned Visit Maximum Start Day \cr
    PFSPTRT \tab Specimen Treatment \cr
    PFTRTAMV \tab Specimen Treatment Amount Value \cr
    PFTRTAMU \tab Specimen Treatment Amount Unit \cr
    PFTRTDUV \tab Specimen Treatment Duration Value \cr
    PFTRTDUU \tab Specimen Treatment Duration Unit \cr
    PFTRTTMV \tab Specimen Treatment Temperature Value \cr
    PFTRTTMU \tab Specimen Treatment Temperature Unit
  }
}
}

