% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/MedicalHistory.R
\name{SUPPMH}
\alias{SUPPMH}
\title{Medical History Domain Supplemental Variables}
\description{
{
  \tabular{ll}{
    \strong{Variable Name} \tab \strong{Variable Label} \cr
    STUDYID \tab Study Identifier \cr
    RDOMAIN  \tab Related Domain Abbreviation \cr
    USUBJID \tab Unique Subject Identifier \cr
    MHSEQ \tab Sequence Number \cr
    IDVAR \tab Identifying Variable \cr
    IDVARVAL \tab Identifying Variable Value \cr
    QNAM \tab Qualifier Variable Name \cr
    QLABEL \tab Qualifier Variable Label \cr
    QVAL \tab Data Value
  }
}
}
\note{
The following table enumerates the values in QNAM and QLABEL variables {
  \tabular{ll}{
    \strong{QNAM} \tab \strong{QLABEL} \cr
    MHAGE \tab Age at Onset \cr
    MHAGEU \tab Age at Onset Units \cr
    MHTOD \tab Time of Day
  }
}
}

